<?php
/**
 * DBCart 商城系统
 *
 * ==========================================================================
 * @link      https://www.dbcart.cn/
 * @copyright 北京珑大钜商科技有限公司，并保留所有权利。
 * @license   https://www.dbcart.cn/license.html License
 * ==========================================================================
 *
 * @author    静静的风 <baron@loongdom.cn>
 *
 */

namespace Admin\Repository;

use Admin\Entity\Delivery;
use Admin\Entity\DeliveryContent;
use Doctrine\ORM\EntityRepository;
use Doctrine\ORM\Query\Expr\Join;

class DeliveryRepository extends EntityRepository
{
    /**
     * 配送列表
     * @return float|int|mixed|string
     */
    public function findDeliveryList(array $search = [], $sortType = '', $sort = '', $languageCode = '')
    {
        $query = $this->getEntityManager()->createQueryBuilder();
        $query->select('d', 'c.deliveryName', 'c.deliveryInfo')
            ->from(Delivery::class, 'd')
            ->leftJoin(DeliveryContent::class, 'c', Join::WITH, 'd.deliveryId = c.deliveryId')
            ->where('c.languageCode = :languageCode')->setParameter('languageCode', empty($languageCode) ? SHOP_FONT_LANGUAGE : $languageCode);

        if (isset($search['deliveryState'])) $query->andWhere('d.deliveryState = :deliveryState')->setParameter('deliveryState', $search['deliveryState']);
        if (!empty($sortType)) $query->orderBy('d.'.$sortType, $sort);
        else $query->orderBy('d.deliveryId', 'ASC');

        return $query->getQuery()->getResult();
    }
}