<?php
/**
 * DBCart 商城系统
 *
 * ==========================================================================
 * @link      https://www.dbcart.cn/
 * @copyright 北京珑大钜商科技有限公司，并保留所有权利。
 * @license   https://www.dbcart.cn/license.html License
 * ==========================================================================
 *
 * @author    静静的风 <baron@loongdom.cn>
 *
 */

namespace Admin\Repository;

use Admin\Entity\SelfLocation;
use Admin\Entity\SelfLocationContent;
use Doctrine\ORM\EntityRepository;
use Doctrine\ORM\Query\Expr\Join;

class SelfLocationRepository extends EntityRepository
{
    /**
     * 自提点列表
     * @return float|int|mixed|string
     */
    public function findSelfLocationList()
    {
        $query = $this->getEntityManager()->createQueryBuilder();
        $query->select('l', 'c.locationName', 'c.locationAddress', 'c.locationUser', 'c.locationBusinessHours', 'c.regionInfo')
            ->from(SelfLocation::class, 'l')
            ->leftJoin(SelfLocationContent::class, 'c', Join::WITH, 'l.locationId = c.locationId')
            ->where('c.languageCode = :languageCode')->setParameter('languageCode', SHOP_FONT_LANGUAGE)
            ->orderBy('l.locationSort', 'ASC')
            ->addOrderBy('l.locationId', 'DESC');

        return $query->getQuery()->getResult();
    }

    /*==========================================下面为前台使用==========================================*/
    /**
     * 前台自提点列表
     * @param $languageCode
     * @return float|int|mixed|string
     */
    public function findShopSelfLocationList($languageCode)
    {
        $query = $this->getEntityManager()->createQueryBuilder();
        $query->select('l', 'c.locationName', 'c.locationAddress', 'c.locationUser', 'c.locationBusinessHours', 'c.regionInfo')
            ->from(SelfLocation::class, 'l')
            ->leftJoin(SelfLocationContent::class, 'c', Join::WITH, 'l.locationId = c.locationId')
            ->where('c.languageCode = :languageCode')->setParameter('languageCode', $languageCode)
            ->andWhere('l.locationState = :locationState')->setParameter('locationState', 1)
            ->orderBy('l.locationSort', 'ASC');

        return $query->getQuery()->getResult();
    }
}