<?php
/**
 * DBCart 商城系统
 *
 * ==========================================================================
 * @link      https://www.dbcart.cn/
 * @copyright 北京珑大钜商科技有限公司，并保留所有权利。
 * @license   https://www.dbcart.cn/license.html License
 * ==========================================================================
 *
 * @author    静静的风 <baron@loongdom.cn>
 *
 */

namespace Admin\Service\Translate;

use Admin\Data\Common;
use Admin\Data\Config;
use Laminas\Crypt\BlockCipher;
use Laminas\Http\Client;
use Laminas\Json\Json;
use Laminas\View\Helper\ServerUrl;

class LoongdomTranslate
{
    private $apiKey;

    public function __construct($translateConfig)
    {
        $this->apiKey = $translateConfig['apiKey'];
    }

    public function cartTranslateBody($query, $from, $to)
    {
        $serviceConfig = Common::readConfigFile('dbcartService');
        if (!$serviceConfig['key'] || !$serviceConfig['code'] || !$serviceConfig['userName']) return ['state' => 'false', 'content' => '服务未绑定'];

        $blockCipher = BlockCipher::factory('openssl', ['algo' => 'aes', 'mode' => 'gcm']);
        $blockCipher->setKey($serviceConfig['key']);

        $serverUrl = new ServerUrl();
        $dataStr = $blockCipher->encrypt(Json::encode([
            'code'          => $serviceConfig['code'],
            'host'          => $serverUrl->getHost(),
            'port'          => $serverUrl->getPort(),
            'query'         => $query,
            'from'          => $from,
            'to'            => $to,
            'translateKey'  => $this->apiKey,
            'versionNumber' => DBCART_VERSION_NUMBER,
        ]));
        $client = new Client(Config::SERVICE_URL . 'translate-api', [
            'adapter' => 'Laminas\Http\Client\Adapter\Curl',
            'curloptions' => [
                CURLOPT_SSL_VERIFYPEER => false
            ]
        ]);
        $client->setHeaders(['Accept' => 'application/json']);
        $client->setMethod('POST');
        $client->setParameterPost([
            'userName'      => $serviceConfig['userName'],
            'systemType'    => 'dbcart',
            'action'        => 'translateStr',
            'dataStr'       => $dataStr
        ]);

        try {
            $response = $client->send();
            if ($response->isSuccess()) {
                $array = Json::decode($response->getBody(), Json::TYPE_ARRAY);
                if ($array['status'] == 'success') return ['state' => 'true', 'content' => $array['result']['text']];
                else return ['state' => 'false', 'message' => $array['message']];
            }
        } catch (\Exception $e) {
            return ['state' => 'false', 'message' => $e->getMessage()];
        }
    }
}