<?php
/**
 * DBCart 商城系统
 *
 * ==========================================================================
 * @link      https://www.dbcart.cn/
 * @copyright 北京珑大钜商科技有限公司，并保留所有权利。
 * @license   https://www.dbcart.cn/license.html License
 * ==========================================================================
 *
 * @author    静静的风 <baron@loongdom.cn>
 *
 */

namespace Cms\Repository;

use Cms\Entity\Cms;
use Cms\Entity\CmsClass;
use Cms\Entity\CmsClassContent;
use Doctrine\ORM\EntityRepository;
use Doctrine\ORM\Query\Expr\Join;

class CmsClassRepository extends EntityRepository
{
    /**
     * 文章分类
     * @return float|int|mixed|string
     */
    public function findAllCmsClass($cmsClassTopId = -1)
    {
        $query = $this->getEntityManager()->createQueryBuilder();
        $query->select('c')
            ->addSelect("(SELECT n.cmsClassName FROM ".CmsClassContent::class." AS n WHERE n.cmsClassId=c.cmsClassId AND n.languageCode='".SHOP_FONT_LANGUAGE."') AS cmsClassName")
            ->from(CmsClass::class, 'c')
            ->orderBy('c.cmsClassTopId', 'ASC')
            ->addOrderBy('c.cmsClassSort', 'ASC');

        if ($cmsClassTopId >= 0) $query->where('c.cmsClassTopId = :cmsClassTopId')->setParameter('cmsClassTopId', $cmsClassTopId);

        return $query->getQuery()->getResult();
    }

    /**
     * 获取分类文章数
     * @param array $search
     * @return int|mixed|string
     */
    public function findClassCmsNum(array $search = [])
    {
        $query = $this->getEntityManager()->createQueryBuilder();
        $query->select('c.cmsClassId')
            ->addSelect('(SELECT COUNT(m.cmsId) FROM '.Cms::class.' AS m WHERE m.cmsClassId=c.cmsClassId) AS cmsNum')
            ->from(CmsClass::class, 'c');

        return $query->getQuery()->getResult();
    }

    /*========================================前台========================================*/
    /**
     * 前台文章分类
     * @param $cmsClassId
     * @param $languageCode
     * @return float|int|mixed|string|null
     * @throws \Doctrine\ORM\NonUniqueResultException
     */
    public function shopCmsClass($cmsClassId, $languageCode)
    {
        $query = $this->getEntityManager()->createQueryBuilder();
        $query->select('c', 'cc.cmsClassName')
            ->from(CmsClass::class, 'c')
            ->innerJoin(CmsClassContent::class, 'cc', Join::WITH, 'c.cmsClassId=cc.cmsClassId')
            ->where('c.cmsClassState = :cmsClassState')->setParameter('cmsClassState', 1)
            ->andWhere('cc.languageCode = :languageCode')->setParameter('languageCode', $languageCode)
            ->andWhere('c.cmsClassId = :cmsClassId')->setParameter('cmsClassId', $cmsClassId);

        return $query->getQuery()->getOneOrNullResult();
    }

    /**
     * 文章分类下级
     * @param $cmsTopClassId
     * @param $languageCode
     * @return float|int|mixed|string
     */
    public function shopSubCmsClass($cmsTopClassId, $languageCode)
    {
        $query = $this->getEntityManager()->createQueryBuilder();
        $query->select('c', 'cc.cmsClassName')
            ->from(CmsClass::class, 'c')
            ->innerJoin(CmsClassContent::class, 'cc', Join::WITH, 'c.cmsClassId=cc.cmsClassId')
            ->where('c.cmsClassState = :cmsClassState')->setParameter('cmsClassState', 1)
            ->andWhere('cc.languageCode = :languageCode')->setParameter('languageCode', $languageCode)
            ->andWhere('c.cmsClassTopId = :cmsClassTopId')->setParameter('cmsClassTopId', $cmsTopClassId)
            ->orderBy('c.cmsClassSort', 'ASC');

        return $query->getQuery()->getResult();
    }
}