<?php
/**
 * DBCart 商城系统
 *
 * ==========================================================================
 * @link      https://www.dbcart.cn/
 * @copyright 北京珑大钜商科技有限公司，并保留所有权利。
 * @license   https://www.dbcart.cn/license.html License
 * ==========================================================================
 *
 * @author    静静的风 <baron@loongdom.cn>
 *
 */

namespace Cms\Service;

use Admin\Data\Common;
use Admin\Data\Config;
use Cms\Entity\CmsContent;
use Doctrine\ORM\EntityManager;

class CmsContentManager
{
    private $entityManager;

    public function __construct(
        EntityManager $entityManager
    )
    {
        $this->entityManager = $entityManager;
    }

    /**
     * 添加或者编辑文章多语言内容
     * @param array $data
     * @param $cmsId
     * @return void
     * @throws \Doctrine\ORM\ORMException
     * @throws \Doctrine\ORM\OptimisticLockException
     */
    public function addOrEditCmsContent(array $data, $cmsId)
    {
        foreach (SHOP_LANGUAGE as $language) {
            $cmsContent = $this->entityManager->getRepository(CmsContent::class)->findOneBy(['cmsId' => $cmsId, 'languageCode' => $language]);
            $emptyState = false;
            if ($cmsContent == null) {
                $cmsContent = new CmsContent();
                $cmsContent->setLanguageCode($language);
                $cmsContent->setCmsId($cmsId);
                $emptyState = true;
            }
            $cmsContent->setCmsTitle($data['cmsTitle'.$language]);
            $cmsContent->setCmsExtendTitle($data['cmsExtendTitle'.$language]);
            $cmsContent->setCmsBody($data['cmsBody'.$language]);
            $cmsContent->setCmsKeywords($data['cmsKeywords'.$language]);
            $cmsContent->setCmsDescription($data['cmsDescription'.$language]);

            if ($emptyState) $this->entityManager->persist($cmsContent);

            $this->entityManager->flush();
        }
    }

    /**
     * 删除文章多语言内容
     * @param $cmsId
     * @return array|null
     * @throws \Doctrine\ORM\ORMException
     * @throws \Doctrine\ORM\OptimisticLockException
     */
    public function deleteCmsContent($cmsId)
    {
        $cmsContent = $this->entityManager->getRepository(CmsContent::class)->findBy(['cmsId' => $cmsId]);
        $body = '';
        foreach ($cmsContent as $contentValue) {
            $body .= $contentValue->getCmsBody();

            $this->entityManager->remove($contentValue);
            $this->entityManager->flush();
        }

        $imageList = Common::bodyImageArray($body);

        if ($imageList) foreach ($imageList as $imageValue) {
            if (stripos($imageValue, 'http') !== false) continue;
            @unlink(Config::CMS_IMAGE_PATH . basename($imageValue));
        }

        return $imageList;
    }
}