<?php
/**
 * DBCart 商城系统
 *
 * ==========================================================================
 * @link      https://www.dbcart.cn/
 * @copyright 北京珑大钜商科技有限公司，并保留所有权利。
 * @license   https://www.dbcart.cn/license.html License
 * ==========================================================================
 *
 * @author    静静的风 <baron@loongdom.cn>
 *
 */

namespace Operation\Service;

use Doctrine\ORM\EntityManager;
use Operation\Entity\CouponContent;

class CouponContentManager
{
    private $entityManager;

    public function __construct(
        EntityManager $entityManager
    )
    {
        $this->entityManager = $entityManager;
    }

    /**
     * 添加或者编辑优惠券内容
     * @param array $data
     * @param $couponId
     * @return void
     * @throws \Doctrine\ORM\ORMException
     * @throws \Doctrine\ORM\OptimisticLockException
     */
    public function addOrEditCouponContent(array $data, $couponId)
    {
        foreach (SHOP_LANGUAGE as $language) {
            $couponContent = $this->entityManager->getRepository(CouponContent::class)->findOneBy(['contentId' => $couponId, 'languageCode' => $language]);
            if ($couponContent) {
                $couponContent->setCouponTitle($data['couponTitle'.$language]);
                $couponContent->setCouponInfo($data['couponInfo'.$language]);
            } else {
                $couponContent = new CouponContent();
                $couponContent->setCouponId($couponId);
                $couponContent->setLanguageCode($language);
                $couponContent->setCouponTitle($data['couponTitle'.$language]);
                $couponContent->setCouponInfo($data['couponInfo'.$language]);

                $this->entityManager->persist($couponContent);
            }

            $this->entityManager->flush();
        }
    }

    /**
     * 删除优惠券内容
     * @param $couponId
     * @return void
     */
    public function deleteCouponContent($couponId)
    {
        $qb = $this->entityManager->createQueryBuilder();
        $qb->delete(CouponContent::class, 'c')->where($qb->expr()->eq('c.couponId', $couponId));
        $qb->getQuery()->execute();
    }
}