<?php
/**
 * DBCart 商城系统
 *
 * ==========================================================================
 * @link      https://www.dbcart.cn/
 * @copyright 北京珑大钜商科技有限公司，并保留所有权利。
 * @license   https://www.dbcart.cn/license.html License
 * ==========================================================================
 *
 * @author    静静的风 <baron@loongdom.cn>
 *
 */

namespace User\Repository;

use Doctrine\ORM\EntityRepository;
use User\Entity\UserWithdraw;
use User\Repository\QuerySearch\WithdrawSearch;

class UserWithdrawRepository extends EntityRepository
{
    /**
     * 余额提现
     * @param array $search
     * @return \Doctrine\ORM\Query
     */
    public function findAllWithdrawList(array $search = [])
    {
        $query = $this->getEntityManager()->createQueryBuilder();
        $query->select('w')
            ->from(UserWithdraw::class, 'w')
            ->orderBy('w.withdrawId', 'DESC');

        $query = WithdrawSearch::querySearchData($search, $query);

        return $query->getQuery();
    }

    /**
     * 提现金额
     * @param array $search
     * @return string
     * @throws \Doctrine\ORM\NoResultException
     * @throws \Doctrine\ORM\NonUniqueResultException
     */
    public function findAllWithdrawAmount(array $search = [])
    {
        $query = $this->getEntityManager()->createQueryBuilder();
        $query->select('SUM(w.moneyChangeNum)')
            ->from(UserWithdraw::class, 'w');

        if(!isset($search['withdraw_state']) || $search['withdraw_state'] <= 0) $search['withdraw_state'] = 2;

        $query = WithdrawSearch::querySearchData($search, $query);

        return number_format($query->getQuery()->getSingleScalarResult(), 2, '.', '');
    }
    /*==============================================下面为前台调用==============================================*/
    /**
     * 会员余额提现列表
     * @param $userId
     * @return \Doctrine\ORM\Query
     */
    public function findUserWithdrawList($userId)
    {
        $query = $this->getEntityManager()->createQueryBuilder();
        $query->select('w')
            ->from(UserWithdraw::class, 'w')
            ->where('w.userId = :userId')->setParameter('userId', $userId)
            ->orderBy('w.withdrawId', 'DESC');

        return $query->getQuery();
    }
}